﻿//***********************************************************************
//                                                                     
//   cs5watermarks 0.9
//Description:Zeigt und ändert die aktuellen Parameter für das Dokumentwasserzeichen
//                                                                     
//   [Ver: 0.9]   [Author: Gerald Singelmann]   [Modif: 10-06-01]
//   [Lang: DE]   [Req: InDesign CS5]   [Creat: 10-06-01]
//                                                                     
//   Bugs & Feedback : gerald{at}cuppascript{dot}com      
//                     www.cuppascript.com    
//                                                                     
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
//*********************************************************************
#target indesign
if (app.documents.length > 0) {
	main();
}

function main() {
	var d = app.activeDocument;

	var wmText = d.watermarkPreferences.watermarkText;
	
	var fontColor = d.watermarkPreferences.watermarkFontColor;
	if (fontColor.constructor.name != "Array") {
		fontColor = [0,0,0];
	} 		
	var fontFamily = d.watermarkPreferences.watermarkFontFamily;
	var fontStyle = d.watermarkPreferences.watermarkFontStyle;
	var fontPointSize = d.watermarkPreferences.watermarkFontPointSize;
	var allFonts = app.fonts.everyItem().name;
	var nFonts = allFonts.length;
	var font_ix = Math.floor(nFonts / 2);
	for (var n = 0; n < nFonts; n++) {
		if (allFonts[n] == fontFamily + "\t" + fontStyle) {
			font_ix = n;
			break;
		}
	}

	var hp_choices = ["links", "mitte", "rechts"];
	switch(d.watermarkPreferences.watermarkHorizontalPosition) {
		case WatermarkHorizontalPositionEnum.WATERMARK_H_CENTER:
			var hp_choice = 1;
			break;
		case WatermarkHorizontalPositionEnum.WATERMARK_H_LEFT:
			var hp_choice = 0;
			break;
		case WatermarkHorizontalPositionEnum.WATERMARK_H_RIGHT:
			var hp_choice = 2;
			break;
	}
	var horizontalOffset = d.watermarkPreferences.watermarkHorizontalOffset;
	
	var verticalOffset = d.watermarkPreferences.watermarkVerticalOffset;
	var vp_choices = ["oben", "mitte", "unten"];
	switch(d.watermarkPreferences.watermarkVerticalPosition) {
		case WatermarkVerticalPositionEnum.WATERMARK_V_CENTER:
			var vp_choice = 1;
			break;
		case WatermarkVerticalPositionEnum.WATERMARK_V_TOP:
			var vp_choice = 0;
			break;
		case WatermarkVerticalPositionEnum.WATERMARK_V_BOTTOM:
			var vp_choice = 2;
			break;
	}
	var opacity = d.watermarkPreferences.watermarkOpacity;
	var rotation = d.watermarkPreferences.watermarkRotation;

	var doPrint = d.watermarkPreferences.watermarkDoPrint;
	var drawInBack = d.watermarkPreferences.watermarkDrawInBack;
	var visibility = d.watermarkPreferences.watermarkVisibility;
	
	var dialog = app.dialogs.add( {name: "Watermark"} );
	var min_width_left = 160;
	var min_width_right = 350;
	with (dialog) {
		with (dialogColumns.add()) {
			with (borderPanels.add()) {
				with (dialogColumns.add()) {
					staticTexts.add( {staticLabel: "Wasserzeichentext: ", minWidth: min_width_left} );
				}
				with (dialogColumns.add()) {
					var text_edit_box = textEditboxes.add({editContents: wmText, minWidth: min_width_right});
				}
			}
			with (borderPanels.add(  )) {
				with (dialogColumns.add()) {
					staticTexts.add( {staticLabel: "Fontfarbe (R, G, B): ", minWidth: min_width_left} );
					staticTexts.add( {staticLabel: "Font: ", minWidth: min_width_left} );
					staticTexts.add( {staticLabel: "Fontgröße: ", minWidth: min_width_left} );
				}
				with (dialogColumns.add()) {
					with (dialogRows.add() ) {
						var rgbr = integerEditboxes.add({editValue: fontColor[0], minimumValue: 0, maximumValue:255, minWidth: 30});
						var rgbg = integerEditboxes.add({editValue: fontColor[1], minimumValue: 0, maximumValue:255, minWidth: 30});
						var rgbb = integerEditboxes.add({editValue: fontColor[2], minimumValue: 0, maximumValue:255, minWidth: 30});
					}
					var the_font = dropdowns.add({ stringList: allFonts, selectedIndex: font_ix, minWidth: min_width_right});
					var the_size = realEditboxes.add( {editValue: fontPointSize, minWidth: 40} );
				}
			}
			with (borderPanels.add( {minWidth: (min_width_left + min_width_right)} )) {
				with (dialogColumns.add()) {
					staticTexts.add( {staticLabel: "Horizontale Position: ", minWidth: min_width_left} );
					staticTexts.add( {staticLabel: "Vertikale Position: ", minWidth: min_width_left} );
					staticTexts.add( {staticLabel: "Deckkraft: ", minWidth: min_width_left} );
					staticTexts.add( {staticLabel: "Rotation: ", minWidth: min_width_left} );
				}
				with (dialogColumns.add()) {
					with (dialogRows.add() ) {
						var hp = dropdowns.add({ stringList: hp_choices, selectedIndex: hp_choice, minWidth: 50});
						staticTexts.add( {staticLabel: "Offset: ", minWidth: 70} );
						var hp_offset = measurementEditboxes.add({editContents: horizontalOffset.toString(), minWidth: 50});
					}
					with (dialogRows.add() ) {
						var vp = dropdowns.add({ stringList: vp_choices, selectedIndex: vp_choice, minWidth: 50});
						staticTexts.add( {staticLabel: "Offset: ", minWidth: 70} );
						var vp_offset = measurementEditboxes.add({editContents: verticalOffset.toString(), minWidth: 50});
					}
					var opacityField = percentEditboxes.add({editValue: opacity, minWidth: 50});
					var rotationField = angleEditboxes.add({editValue: rotation, minWidth: 50});
				}
			}
			with (borderPanels.add()) {
				with (dialogColumns.add()) {
					staticTexts.add( {staticLabel: "  ", minWidth: min_width_left} );
				}
				with (dialogColumns.add()) {
					var sichtbar = checkboxControls.add({staticLabel: "Sichtbar im Dokument", checkedState: visibility, minWidth: min_width_right});
					var druckbar = checkboxControls.add({staticLabel: "Sichtbar im Druck", checkedState: doPrint, minWidth: min_width_right});
					var hinten = checkboxControls.add({staticLabel: "Im Hintergrund", checkedState: drawInBack, minWidth: min_width_right});
				}
			}
		}
	}
	if (dialog.show() == false) {
		dialog.destroy();
	} else {
		d.watermarkPreferences.watermarkText = text_edit_box.editContents;
		// try {
			d.watermarkPreferences.watermarkFontColor = [rgbr.editValue, rgbg.editValue, rgbb.editValue];
		// } catch (e) {}
		var font = allFonts[the_font.selectedIndex].split("\t");
		d.watermarkPreferences.watermarkFontFamily = font[0];
		d.watermarkPreferences.watermarkFontStyle = font[1];
		d.watermarkPreferences.watermarkFontPointSize = the_size.editValue;
		//-----------------------------------------
		switch(hp.selectedIndex) {
			case 0:
				d.watermarkPreferences.watermarkHorizontalPosition = WatermarkHorizontalPositionEnum.WATERMARK_H_LEFT;
			break;
			case 1:
				d.watermarkPreferences.watermarkHorizontalPosition = WatermarkHorizontalPositionEnum.WATERMARK_H_CENTER;
			break;
			case 2:
				d.watermarkPreferences.watermarkHorizontalPosition = WatermarkHorizontalPositionEnum.WATERMARK_H_RIGHT;
			break;
		}
		switch(vp.selectedIndex) {
			case 0:
				d.watermarkPreferences.watermarkVerticalPosition = WatermarkVerticalPositionEnum.WATERMARK_V_TOP;
			break;
			case 1:
				d.watermarkPreferences.watermarkVerticalPosition = WatermarkVerticalPositionEnum.WATERMARK_V_CENTER;
			break;
			case 2:
				d.watermarkPreferences.watermarkVerticalPosition = WatermarkVerticalPositionEnum.WATERMARK_V_BOTTOM;
			break;
		}
		d.watermarkPreferences.watermarkHorizontalOffset = hp_offset.editValue;
		d.watermarkPreferences.watermarkVerticalOffset = vp_offset.editValue;
		d.watermarkPreferences.watermarkOpacity = opacityField.editValue;
		d.watermarkPreferences.watermarkRotation = rotationField.editValue;
		//-----------------------------------------
		d.watermarkPreferences.watermarkVisibility = sichtbar.checkedState;
		d.watermarkPreferences.watermarkDoPrint = druckbar.checkedState;
		d.watermarkPreferences.watermarkDrawInBack = hinten.checkedState;
		
		dialog.destroy();
	}

}
